@@ -19,19 +19,22 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include <linux/version.h>
 #include <linux/module.h>
 #include <linux/slab.h>
 #include <linux/proc_fs.h>
 #include <linux/sysctl.h>
-#include <asm/errno.h>
-#include <asm/io.h>
 #include <linux/types.h>
 #include <linux/i2c.h>
+#include <linux/i2c-proc.h>
 #include <linux/ipmi.h>
-#include "version.h"
-#include "sensors.h"
 #include <linux/init.h>
+#include <asm/errno.h>
+#include <asm/io.h>
+#include "version.h"
+
+/*
+#define DEBUG 1
+*/
 
 static unsigned short normal_i2c[] = { SENSORS_I2C_END };
 static unsigned short normal_i2c_range[] = { SENSORS_I2C_END };
@@ -40,11 +43,6 @@ static unsigned int normal_isa_range[] = { SENSORS_ISA_END };
 
 SENSORS_INSMOD_1(bmcsensors);
 
-#ifdef MODULE
-extern int init_module(void);
-extern int cleanup_module(void);
-#endif				/* MODULE */
-
 struct bmcsensors_data {
 	struct semaphore lock;
 	int sysctl_id;
@@ -56,13 +54,6 @@ struct bmcsensors_data {
 	u8 alarms;
 };
 
-#ifdef MODULE
-static
-#else
-extern
-#endif
-int __init sensors_bmcsensors_init(void);
-static int __init bmcsensors_cleanup(void);
 
 static int bmcsensors_attach_adapter(struct i2c_adapter *adapter);
 static int bmcsensors_detect(struct i2c_adapter *adapter, int address,
@@ -70,8 +61,6 @@ static int bmcsensors_detect(struct i2c_adapter *adapter, int address,
 static int bmcsensors_detach_client(struct i2c_client *client);
 static int bmcsensors_command(struct i2c_client *client, unsigned int cmd,
 			   void *arg);
-static void bmcsensors_inc_use(struct i2c_client *client);
-static void bmcsensors_dec_use(struct i2c_client *client);
 
 static void bmcsensors_update_client(struct i2c_client *client);
 static int bmcsensors_find(int *address);
@@ -92,14 +81,13 @@ static void bmcsensors_get_reading(struct i2c_client *client, int i);
 static int bmcsensors_id = 0;
 
 static struct i2c_driver bmcsensors_driver = {
-	/* name */ "BMC Sensors driver",
-	/* id */ I2C_DRIVERID_BMCSENSORS,
-	/* flags */ I2C_DF_NOTIFY,
-	/* attach_adapter */ &bmcsensors_attach_adapter,
-	/* detach_client */ &bmcsensors_detach_client,
-	/* command */ &bmcsensors_command,
-	/* inc_use */ &bmcsensors_inc_use,
-	/* dec_use */ &bmcsensors_dec_use
+	.owner		= THIS_MODULE,
+	.name		= "BMC Sensors driver",
+	.id		= I2C_DRIVERID_BMCSENSORS,
+	.flags		= I2C_DF_NOTIFY,
+	.attach_adapter	= bmcsensors_attach_adapter,
+	.detach_client	= bmcsensors_detach_client,
+	.command	= bmcsensors_command,
 };
 
 static struct bmcsensors_data bmc_data;
@@ -116,7 +104,6 @@ struct i2c_client bmc_client = {
 
 static bmcsensors_initialized;
 
-
 #define MAX_SDR_ENTRIES 50
 #define SDR_LIMITS 8
 #define SDR_MAX_ID_LENGTH 16
@@ -149,6 +136,16 @@ struct sdrdata {
 static struct sdrdata sdrd[MAX_SDR_ENTRIES];
 static int sdrd_count;
 
+
+/* -- SENSORS SYSCTL START -- */
+#define BMC_SYSCTL_IN1 1000
+#define BMC_SYSCTL_TEMP1 1100
+#define BMC_SYSCTL_CURR1 1200
+#define BMC_SYSCTL_FAN1 1300
+#define BMC_SYSCTL_ALARMS 5000
+
+/* -- SENSORS SYSCTL END -- */
+
 #define MAX_PROC_ENTRIES (MAX_SDR_ENTRIES + 5)
 #define MAX_PROCNAME_SIZE 8
 static ctl_table *bmcsensors_dir_table;
@@ -394,8 +391,7 @@ static void bmcsensors_build_proc_table()
 	bmcsensors_dir_table[sdrd_count].ctl_name = 0;
 
 	if ((i = i2c_register_entry(&bmc_client, "bmc",
-				    bmcsensors_dir_table,
-				    THIS_MODULE)) < 0) {
+				    bmcsensors_dir_table)) < 0) {
 		printk(KERN_INFO "bmcsensors.o: i2c registration failed.\n");
 		kfree(bmcsensors_dir_table);
 		kfree(bmcsensors_proc_name_pool);
@@ -572,7 +568,7 @@ static int bmcsensors_rcv_sdr_msg(struct ipmi_msg *msg, int state)
 		if(type == 0x10) {
 			printk(KERN_INFO "bmcsensors.o: Generic Device acc=0x%x; slv=0x%x; lun=0x%x; type=0x%x; \"%s\"\n",
 				data[8], data[9], data[10], data[13], id);
-		else if(type == 0x11) {
+		} else if(type == 0x11) {
 			printk(KERN_INFO "bmcsensors.o: FRU Device acc=0x%x; slv=0x%x; log=0x%x; ch=0x%x; type=0x%x; \"%s\"\n",
 				data[8], data[9], data[10], data[11], data[13], id);
 		} else {
@@ -806,19 +802,6 @@ static int bmcsensors_detach_client(struct i2c_client *client)
 	return 0;
 }
 
-static void bmcsensors_inc_use(struct i2c_client *client)
-{
-#ifdef MODULE
-	MOD_INC_USE_COUNT;
-#endif
-}
-
-static void bmcsensors_dec_use(struct i2c_client *client)
-{
-#ifdef MODULE
-	MOD_DEC_USE_COUNT;
-#endif
-}
 
 static void bmc_do_pause(unsigned int amount)
 {
@@ -972,56 +955,22 @@ static void bmcsensors_alarms(struct i2c_client *client, int operation, int ctl_
 #endif
 }
 
-static int __init sensors_bmcsensors_init(void)
+static int __init sm_bmcsensors_init(void)
 {
-	int res, addr;
-
 	printk(KERN_INFO "bmcsensors.o version %s (%s)\n", LM_VERSION, LM_DATE);
-	bmcsensors_initialized = 0;
-
-	if ((res = i2c_add_driver(&bmcsensors_driver))) {
-		printk(KERN_ERR
-		   "bmcsensors.o: Driver registration failed, module not inserted.\n");
-		bmcsensors_cleanup();
-		return res;
-	}
-	bmcsensors_initialized = 1;
-	return 0;
+	return i2c_add_driver(&bmcsensors_driver);
 }
 
-static int __init bmcsensors_cleanup(void)
+static void __exit sm_bmcsensors_exit(void)
 {
-	int res;
-
-	if (bmcsensors_initialized >= 1) {
-		if ((res = i2c_del_driver(&bmcsensors_driver))) {
-			printk(KERN_WARNING
-			    "bmcsensors.o: Driver deregistration failed, module not removed.\n");
-			return res;
-		}
-		bmcsensors_initialized--;
-	}
-	return 0;
+	i2c_del_driver(&bmcsensors_driver);
 }
 
-EXPORT_NO_SYMBOLS;
 
-#ifdef MODULE
 
 MODULE_AUTHOR("Mark D. Studebaker <mdsxyz123@yahoo.com>");
 MODULE_DESCRIPTION("IPMI BMC sensors");
-#ifdef MODULE_LICENSE
 MODULE_LICENSE("GPL");
-#endif
 
-int init_module(void)
-{
-	return sensors_bmcsensors_init();
-}
-
-int cleanup_module(void)
-{
-	return bmcsensors_cleanup();
-}
-
-#endif				/* MODULE */
+module_init(sm_bmcsensors_init);
+module_exit(sm_bmcsensors_exit);
