@@ -18,32 +18,20 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-#include <linux/version.h>
 #include <linux/module.h>
 #include <linux/slab.h>
 #include <linux/proc_fs.h>
 #include <linux/ioport.h>
 #include <linux/sysctl.h>
-#include <asm/errno.h>
-#include <asm/io.h>
 #include <linux/types.h>
 #include <linux/i2c.h>
-#include "version.h"
-#include "sensors.h"
+#include <linux/i2c-proc.h>
 #include <linux/init.h>
+#include <asm/errno.h>
+#include <asm/io.h>
+#include "version.h"
 
-#ifdef MODULE_LICENSE
 MODULE_LICENSE("GPL");
-#endif
-
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,2,18)) || \
-    (LINUX_VERSION_CODE == KERNEL_VERSION(2,3,0))
-#define init_MUTEX(s) do { *(s) = MUTEX; } while(0)
-#endif
-
-#ifndef THIS_MODULE
-#define THIS_MODULE NULL
-#endif
 
 /* Addresses to scan */
 static unsigned short normal_i2c[] = { SENSORS_I2C_END };
@@ -92,7 +80,7 @@ SENSORS_INSMOD_3(lm78, lm78j, lm79);
 #define IN_TO_REG(val)  (SENSORS_LIMIT((((val) * 10 + 8)/16),0,255))
 #define IN_FROM_REG(val) (((val) *  16) / 10)
 
-extern inline u8 FAN_TO_REG(long rpm, int div)
+static inline u8 FAN_TO_REG(long rpm, int div)
 {
 	if (rpm == 0)
 		return 255;
@@ -162,11 +150,6 @@ extern inline u8 FAN_TO_REG(long rpm, int div)
 #define LM78_INIT_TEMP_OVER 600
 #define LM78_INIT_TEMP_HYST 500
 
-#ifdef MODULE
-extern int init_module(void);
-extern int cleanup_module(void);
-#endif				/* MODULE */
-
 /* There are some complications in a module like this. First off, LM78 chips
    may be both present on the SMBus and the ISA bus, and we have to handle
    those cases separately at some places. Second, there might be several
@@ -209,22 +192,10 @@ struct lm78_data {
 };
 
 
-#ifdef MODULE
-static
-#else
-extern
-#endif
-int __init sensors_lm78_init(void);
-static int __init lm78_cleanup(void);
-
 static int lm78_attach_adapter(struct i2c_adapter *adapter);
 static int lm78_detect(struct i2c_adapter *adapter, int address,
 		       unsigned short flags, int kind);
 static int lm78_detach_client(struct i2c_client *client);
-static int lm78_command(struct i2c_client *client, unsigned int cmd,
-			void *arg);
-static void lm78_inc_use(struct i2c_client *client);
-static void lm78_dec_use(struct i2c_client *client);
 
 static int lm78_read_value(struct i2c_client *client, u8 register);
 static int lm78_write_value(struct i2c_client *client, u8 register,
@@ -247,22 +218,52 @@ static void lm78_fan_div(struct i2c_client *client, int operation,
 			 int ctl_name, int *nrels_mag, long *results);
 
 static struct i2c_driver lm78_driver = {
-	/* name */ "LM78(-J) and LM79 sensor driver",
-	/* id */ I2C_DRIVERID_LM78,
-	/* flags */ I2C_DF_NOTIFY,
-	/* attach_adapter */ &lm78_attach_adapter,
-	/* detach_client */ &lm78_detach_client,
-	/* command */ &lm78_command,
-	/* inc_use */ &lm78_inc_use,
-	/* dec_use */ &lm78_dec_use
+	.owner		= THIS_MODULE,
+	.name		= "LM78(-J) and LM79 sensor driver",
+	.id		= I2C_DRIVERID_LM78,
+	.flags		= I2C_DF_NOTIFY,
+	.attach_adapter	= lm78_attach_adapter,
+	.detach_client	= lm78_detach_client,
 };
 
-/* Used by lm78_init/cleanup */
-static int __initdata lm78_initialized = 0;
-
 static int lm78_id = 0;
 
 /* The /proc/sys entries */
+
+/* -- SENSORS SYSCTL START -- */
+#define LM78_SYSCTL_IN0 1000	/* Volts * 100 */
+#define LM78_SYSCTL_IN1 1001
+#define LM78_SYSCTL_IN2 1002
+#define LM78_SYSCTL_IN3 1003
+#define LM78_SYSCTL_IN4 1004
+#define LM78_SYSCTL_IN5 1005
+#define LM78_SYSCTL_IN6 1006
+#define LM78_SYSCTL_FAN1 1101	/* Rotations/min */
+#define LM78_SYSCTL_FAN2 1102
+#define LM78_SYSCTL_FAN3 1103
+#define LM78_SYSCTL_TEMP 1200	/* Degrees Celcius * 10 */
+#define LM78_SYSCTL_VID 1300	/* Volts * 100 */
+#define LM78_SYSCTL_FAN_DIV 2000	/* 1, 2, 4 or 8 */
+#define LM78_SYSCTL_ALARMS 2001	/* bitvector */
+
+#define LM78_ALARM_IN0 0x0001
+#define LM78_ALARM_IN1 0x0002
+#define LM78_ALARM_IN2 0x0004
+#define LM78_ALARM_IN3 0x0008
+#define LM78_ALARM_IN4 0x0100
+#define LM78_ALARM_IN5 0x0200
+#define LM78_ALARM_IN6 0x0400
+#define LM78_ALARM_FAN1 0x0040
+#define LM78_ALARM_FAN2 0x0080
+#define LM78_ALARM_FAN3 0x0800
+#define LM78_ALARM_TEMP 0x0010
+#define LM78_ALARM_BTI 0x0020
+#define LM78_ALARM_CHAS 0x1000
+#define LM78_ALARM_FIFO 0x2000
+#define LM78_ALARM_SMI_IN 0x4000
+
+/* -- SENSORS SYSCTL END -- */
+
 /* These files are created for each detected LM78. This is just a template;
    though at first sight, you might think we could use a statically
    allocated list, we need some way to get back to the parent - which
@@ -305,7 +306,7 @@ static ctl_table lm78_dir_table_template[] = {
      * lm78_driver is inserted (when this module is loaded), for each
        available adapter
      * when a new adapter is inserted (and lm78_driver is still present) */
-int lm78_attach_adapter(struct i2c_adapter *adapter)
+static int lm78_attach_adapter(struct i2c_adapter *adapter)
 {
 	return i2c_detect(adapter, &addr_data, lm78_detect);
 }
@@ -444,8 +445,7 @@ int lm78_detect(struct i2c_adapter *adapter, int address,
 	/* Register a new directory entry with module sensors */
 	if ((i = i2c_register_entry(new_client,
 					type_name,
-					lm78_dir_table_template,
-					THIS_MODULE)) < 0) {
+					lm78_dir_table_template)) < 0) {
 		err = i;
 		goto ERROR4;
 	}
@@ -469,7 +469,7 @@ int lm78_detect(struct i2c_adapter *adapter, int address,
 	return err;
 }
 
-int lm78_detach_client(struct i2c_client *client)
+static int lm78_detach_client(struct i2c_client *client)
 {
 	int err;
 
@@ -489,29 +489,6 @@ int lm78_detach_client(struct i2c_client *client)
 	return 0;
 }
 
-/* No commands defined yet */
-int lm78_command(struct i2c_client *client, unsigned int cmd, void *arg)
-{
-	return 0;
-}
-
-/* Nothing here yet */
-void lm78_inc_use(struct i2c_client *client)
-{
-#ifdef MODULE
-	MOD_INC_USE_COUNT;
-#endif
-}
-
-/* Nothing here yet */
-void lm78_dec_use(struct i2c_client *client)
-{
-#ifdef MODULE
-	MOD_DEC_USE_COUNT;
-#endif
-}
-
-
 /* The SMBus locks itself, but ISA access must be locked explicitely! 
    We don't want to lock the whole ISA bus, so we lock each client
    separately.
@@ -519,7 +496,7 @@ void lm78_dec_use(struct i2c_client *client)
    would slow down the LM78 access and should not be necessary. 
    There are some ugly typecasts here, but the good new is - they should
    nowhere else be necessary! */
-int lm78_read_value(struct i2c_client *client, u8 reg)
+static int lm78_read_value(struct i2c_client *client, u8 reg)
 {
 	int res;
 	if (i2c_is_isa_client(client)) {
@@ -539,7 +516,7 @@ int lm78_read_value(struct i2c_client *client, u8 reg)
    would slow down the LM78 access and should not be necessary. 
    There are some ugly typecasts here, but the good new is - they should
    nowhere else be necessary! */
-int lm78_write_value(struct i2c_client *client, u8 reg, u8 value)
+static int lm78_write_value(struct i2c_client *client, u8 reg, u8 value)
 {
 	if (i2c_is_isa_client(client)) {
 		down(&(((struct lm78_data *) (client->data))->lock));
@@ -552,7 +529,7 @@ int lm78_write_value(struct i2c_client *client, u8 reg, u8 value)
 }
 
 /* Called when we have found a new LM78. It should set limits, etc. */
-void lm78_init_client(struct i2c_client *client)
+static void lm78_init_client(struct i2c_client *client)
 {
 	int vid;
 
@@ -614,7 +591,7 @@ void lm78_init_client(struct i2c_client *client)
 
 }
 
-void lm78_update_client(struct i2c_client *client)
+static void lm78_update_client(struct i2c_client *client)
 {
 	struct lm78_data *data = client->data;
 	int i;
@@ -792,11 +769,15 @@ void lm78_alarms(struct i2c_client *client, int operation, int ctl_name,
 	}
 }
 
+/* Note: we save and restore the fan minimum here, because its value is
+   determined in part by the fan divisor.  This follows the principle of
+   least surprise: the user doesn't expect the fan minimum to change just
+   because the divisor changed. */
 void lm78_fan_div(struct i2c_client *client, int operation, int ctl_name,
 		  int *nrels_mag, long *results)
 {
 	struct lm78_data *data = client->data;
-	int old;
+	int old, min;
 
 	if (operation == SENSORS_PROC_REAL_INFO)
 		*nrels_mag = 0;
@@ -809,64 +790,44 @@ void lm78_fan_div(struct i2c_client *client, int operation, int ctl_name,
 	} else if (operation == SENSORS_PROC_REAL_WRITE) {
 		old = lm78_read_value(client, LM78_REG_VID_FANDIV);
 		if (*nrels_mag >= 2) {
+			min = FAN_FROM_REG(data->fan_min[1], 
+					DIV_FROM_REG(data->fan_div[1]));
 			data->fan_div[1] = DIV_TO_REG(results[1]);
 			old = (old & 0x3f) | (data->fan_div[1] << 6);
+			data->fan_min[1] = FAN_TO_REG(min,
+					DIV_FROM_REG(data->fan_div[1]));
+			lm78_write_value(client, LM78_REG_FAN_MIN(2),
+					data->fan_min[1]);
 		}
 		if (*nrels_mag >= 1) {
+			min = FAN_FROM_REG(data->fan_min[0],
+					DIV_FROM_REG(data->fan_div[0]));
 			data->fan_div[0] = DIV_TO_REG(results[0]);
 			old = (old & 0xcf) | (data->fan_div[0] << 4);
+			data->fan_min[0] = FAN_TO_REG(min,
+					DIV_FROM_REG(data->fan_div[0]));
+			lm78_write_value(client, LM78_REG_FAN_MIN(1),
+					data->fan_min[0]);
 			lm78_write_value(client, LM78_REG_VID_FANDIV, old);
 		}
 	}
 }
 
-int __init sensors_lm78_init(void)
+static int __init sm_lm78_init(void)
 {
-	int res;
-
 	printk("lm78.o version %s (%s)\n", LM_VERSION, LM_DATE);
-	lm78_initialized = 0;
-
-	if ((res = i2c_add_driver(&lm78_driver))) {
-		printk
-		    ("lm78.o: Driver registration failed, module not inserted.\n");
-		lm78_cleanup();
-		return res;
-	}
-	lm78_initialized++;
-	return 0;
+	return i2c_add_driver(&lm78_driver);
 }
 
-int __init lm78_cleanup(void)
+static void __exit sm_lm78_exit(void)
 {
-	int res;
-
-	if (lm78_initialized >= 1) {
-		if ((res = i2c_del_driver(&lm78_driver))) {
-			printk
-			    ("lm78.o: Driver deregistration failed, module not removed.\n");
-			return res;
-		}
-		lm78_initialized--;
-	}
-	return 0;
+	i2c_del_driver(&lm78_driver);
 }
 
-EXPORT_NO_SYMBOLS;
 
-#ifdef MODULE
 
 MODULE_AUTHOR("Frodo Looijaard <frodol@dds.nl>");
 MODULE_DESCRIPTION("LM78, LM78-J and LM79 driver");
 
-int init_module(void)
-{
-	return sensors_lm78_init();
-}
-
-int cleanup_module(void)
-{
-	return lm78_cleanup();
-}
-
-#endif				/* MODULE */
+module_init(sm_lm78_init);
+module_exit(sm_lm78_exit);
